@@ -1,4 +1,5 @@
 from ormar.queryset.actions.filter_action import FilterAction
 from ormar.queryset.actions.order_action import OrderAction
+from ormar.queryset.actions.select_action import SelectAction
 
-__all__ = ["FilterAction", "OrderAction"]
+__all__ = ["FilterAction", "OrderAction", "SelectAction"]
